import React from 'react';
import { icons } from '../icons/icons';

export default function SvgIcon({ className, width, height, color, style }) {
    // Create a new SVG string with custom attributes if provided
    const customizeSvg = (svgString) => {
        if (!svgString) return '';

        // If no customization needed, return the original SVG
        if (!width && !height && !color) return svgString;

        // Parse the SVG to modify attributes
        let modifiedSvg = svgString;

        // Replace width if provided
        if (width) {
            modifiedSvg = modifiedSvg.replace(/width=['"]([^'"]*)['"]/g, `width="${width}"`);
        }

        // Replace height if provided
        if (height) {
            modifiedSvg = modifiedSvg.replace(/height=['"]([^'"]*)['"]/g, `height="${height}"`);
        }

        // Replace fill color if provided
        if (color) {
            modifiedSvg = modifiedSvg.replace(/fill=['"]currentColor['"]/g, `fill="${color}"`);
        }

        return modifiedSvg;
    };

    return (
        <span
            className={className}
            style={{
                display: 'inline-block',
                lineHeight: 0,
                ...style,
            }}
            dangerouslySetInnerHTML={{
                __html: customizeSvg(icons[className] || ''),
            }}
        />
    );
}
